@@ -13,6 +13,7 @@ from .series import api_ns_list_series
 from .subtitles import api_ns_list_subtitles
 from .system import api_ns_list_system
 from .webhooks import api_ns_list_webhooks
+from .plex import api_ns_list_plex
 from .swaggerui import swaggerui_api_params
 
 api_ns_list = [
@@ -26,6 +27,7 @@ api_ns_list = [
     api_ns_list_subtitles,
     api_ns_list_system,
     api_ns_list_webhooks,
+    api_ns_list_plex,
 ]
 
 authorizations = {
