@@ -9,6 +9,7 @@ from flask_restx import Resource, Namespace, reqparse
 from bs4 import BeautifulSoup as bso
 
 from app.database import TableEpisodes, TableShows, TableMovies, database, select
+from app.config import settings
 from subtitles.mass_download import episode_download_subtitles, movies_download_subtitles
 from app.logger import logger
 from ..plex.security import sanitize_log_data
@@ -20,6 +21,77 @@ api_ns_webhooks_plex = Namespace('Webhooks Plex', description='Webhooks endpoint
                                                               'trigger a subtitles search when playback start.')
 
 
+def _is_relevant_server(payload):
+    """Check if webhook is from our configured Plex server."""
+    instance_name = settings.general.get('instance_name', 'Bazarr')
+    
+    server_uuid = payload.get('Server', {}).get('uuid', '')
+    configured_server = settings.plex.get('server_machine_id', '')
+    
+    if not configured_server:
+        # No server configured, process all (backward compatible)
+        logger.debug(f'PLEX WEBHOOK [{instance_name}]: No server configured, processing all')
+        return True
+    
+    if not server_uuid:
+        # Can't determine server from payload, process anyway
+        logger.debug(f'PLEX WEBHOOK [{instance_name}]: No server UUID in payload, processing')
+        return True
+    
+    if server_uuid == configured_server:
+        logger.debug(f'PLEX WEBHOOK [{instance_name}]: Server UUID matches ({server_uuid[:8]}...)')
+        return True
+    
+    logger.debug(f'PLEX WEBHOOK [{instance_name}]: Server UUID mismatch '
+                f'(got {server_uuid[:8]}..., expected {configured_server[:8]}...), skipping')
+    return False
+
+
+def _is_relevant_library(payload):
+    """Check if webhook is for a library this instance manages."""
+    instance_name = settings.general.get('instance_name', 'Bazarr')
+    
+    metadata = payload.get('Metadata', {})
+    library_section_id = metadata.get('librarySectionID')
+    library_section_title = metadata.get('librarySectionTitle', '')
+    media_type = metadata.get('type', '')
+    
+    # Determine which library config to check
+    if media_type == 'episode':
+        configured_lib_ids = settings.plex.get('series_library_ids', [])
+        configured_lib_names = settings.plex.get('series_library', [])
+    else:
+        configured_lib_ids = settings.plex.get('movie_library_ids', [])
+        configured_lib_names = settings.plex.get('movie_library', [])
+    
+    # Normalize to lists
+    if isinstance(configured_lib_ids, str):
+        configured_lib_ids = [configured_lib_ids] if configured_lib_ids else []
+    if isinstance(configured_lib_names, str):
+        configured_lib_names = [configured_lib_names] if configured_lib_names else []
+    
+    # If no libraries configured, process all (backward compatible)
+    if not configured_lib_ids and not configured_lib_names:
+        logger.debug(f'PLEX WEBHOOK [{instance_name}]: No libraries configured, processing all')
+        return True
+    
+    # Check by ID first (100% reliable)
+    if configured_lib_ids and library_section_id:
+        if str(library_section_id) in [str(lid) for lid in configured_lib_ids]:
+            logger.debug(f'PLEX WEBHOOK [{instance_name}]: Library ID {library_section_id} matches')
+            return True
+    
+    # Fallback to name matching
+    if configured_lib_names and library_section_title:
+        if library_section_title in configured_lib_names:
+            logger.debug(f'PLEX WEBHOOK [{instance_name}]: Library name "{library_section_title}" matches')
+            return True
+    
+    logger.debug(f'PLEX WEBHOOK [{instance_name}]: Library "{library_section_title}" '
+                f'(ID: {library_section_id}) not configured, skipping')
+    return False
+
+
 @api_ns_webhooks_plex.route('webhooks/plex')
 class WebHooksPlex(Resource):
     post_request_parser = reqparse.RequestParser()
@@ -52,7 +124,7 @@ class WebHooksPlex(Resource):
             
             event = parsed_json_webhook['event']
             
-            if event not in ['media.play']:
+            if event not in ['media.play', 'playback.started']:
                 logger.debug('PLEX WEBHOOK: Ignoring unhandled event "%s"', event)
                 return 'Unhandled event', 204
             
@@ -73,6 +145,14 @@ class WebHooksPlex(Resource):
             logger.error('PLEX WEBHOOK: Unexpected error: %s', str(e))
             return "Unexpected error processing webhook", 500
 
+        # Filter by server UUID - skip if from different Plex server
+        if not _is_relevant_server(parsed_json_webhook):
+            return 'Event from different Plex server, skipping', 204
+        
+        # Filter by library ID/name - skip if for different library
+        if not _is_relevant_library(parsed_json_webhook):
+            return 'Event for different library, skipping', 204
+
         media_type = parsed_json_webhook['Metadata']['type']
 
         if media_type == 'episode':
@@ -113,7 +193,7 @@ class WebHooksPlex(Resource):
                     .first()
 
                 if sonarrEpisodeId:
-                    episode_download_subtitles(no=sonarrEpisodeId.sonarrEpisodeId, send_progress=True)
+                    episode_download_subtitles(no=sonarrEpisodeId.sonarrEpisodeId)
         else:
             try:
                 movie_imdb_id = [x['imdb'] for x in ids if 'imdb' in x][0]
