@@ -153,12 +153,12 @@ subliminal.region.backend.sync()
 
 if not os.path.exists(os.path.join(args.config_dir, 'config', 'releases.txt')):
     from app.check_update import check_releases
-    check_releases()
+    check_releases(startup=True)
     logging.debug("BAZARR Created releases file")
 
 if not os.path.exists(os.path.join(args.config_dir, 'config', 'announcements.txt')):
     from app.announcements import get_announcements_to_file
-    get_announcements_to_file()
+    get_announcements_to_file(startup=True)
     logging.debug("BAZARR Created announcements file")
 
 # Move GA visitor from config to dedicated file
