@@ -2,18 +2,21 @@
 
 import os
 import logging
+import operator
 from constants import MINIMUM_VIDEO_SIZE
 
 from sqlalchemy.exc import IntegrityError
 from datetime import datetime
+from functools import reduce
 
-from app.database import database, TableShows, TableEpisodes, delete, update, insert, select
+from app.database import database, TableShows, TableEpisodes, delete, update, insert, select, get_exclusion_clause
 from app.config import settings
 from utilities.path_mappings import path_mappings
 from subtitles.indexer.series import store_subtitles, series_full_scan_subtitles
 from subtitles.mass_download import episode_download_subtitles
 from app.event_handler import event_stream
 from sonarr.info import get_sonarr_info
+from app.jobs_queue import jobs_queue
 
 from .parser import episodeParser
 from .utils import get_episodes_from_sonarr_api, get_episodesFiles_from_sonarr_api
@@ -38,12 +41,17 @@ def get_episodes_monitored_table(series_id):
     return episode_dict
 
 
-def update_all_episodes():
-    series_full_scan_subtitles()
-    logging.info('BAZARR All existing episode subtitles indexed from disk.')
+def check_actual_file_size(original_episode_path):
+    try:
+        bazarr_file_size = \
+            os.path.getsize(path_mappings.path_replace(original_episode_path))
+    except OSError:
+        bazarr_file_size = 0
+
+    return bazarr_file_size > MINIMUM_VIDEO_SIZE
 
 
-def sync_episodes(series_id, send_event=True, defer_search=False):
+def sync_episodes(series_id, defer_search=False, is_signalr=False):
     logging.debug(f'BAZARR Starting episodes sync from Sonarr for series ID {series_id}.')
     apikey_sonarr = settings.sonarr.apikey
 
@@ -55,11 +63,11 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
                                                   TableEpisodes.path,
                                                   TableEpisodes.sonarrSeriesId)
                                            .where(TableEpisodes.sonarrSeriesId == series_id)).all()]
-        current_episodes_db_kv = [x.items() for x in [y._asdict()['TableEpisodes'].__dict__ for y in
-                                                      database.execute(
-                                                          select(TableEpisodes)
-                                                          .where(TableEpisodes.sonarrSeriesId == series_id))
-                                                      .all()]]
+        current_episodes_in_db_row_as_dict = {row[0].sonarrEpisodeId: row[0].to_dict() for row in
+                                              database.execute(
+                                                  select(TableEpisodes)
+                                                  .where(TableEpisodes.sonarrSeriesId == series_id))
+                                              .all()}
     else:
         return
 
@@ -71,7 +79,9 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
     episodes = get_episodes_from_sonarr_api(apikey_sonarr=apikey_sonarr, series_id=series_id)
     if episodes:
         # For Sonarr v3, we need to update episodes to integrate the episodeFile API endpoint results
-        if not get_sonarr_info.is_legacy():
+        # We skip this if the episodes already contain an episodeFile structure (added with Sonarr v4.0.9.2421)
+        if (not get_sonarr_info.is_legacy() and
+                any([episode.get('hasFile') and not episode.get('episodeFileId') for episode in episodes])):
             episodeFiles = get_episodesFiles_from_sonarr_api(apikey_sonarr=apikey_sonarr, series_id=series_id)
             for episode in episodes:
                 if episodeFiles and episode['hasFile']:
@@ -85,45 +95,38 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
             skipped_count = 0
 
         for episode in episodes:
-            if 'hasFile' in episode:
-                if episode['hasFile'] is True:
-                    if 'episodeFile' in episode:
-                        # monitored_status_db = get_episodes_monitored_status(episode['episodeFileId'])
-                        if sync_monitored:
-                            try:
-                                monitored_status_db = bool_map[episodes_monitored[episode['episodeFileId']]]
-                            except KeyError:
-                                monitored_status_db = None
+            if 'hasFile' in episode and episode['hasFile'] and 'episodeFile' in episode:
+                if sync_monitored:
+                    try:
+                        monitored_status_db = bool_map[episodes_monitored[episode['episodeFileId']]]
+                    except KeyError:
+                        monitored_status_db = None
 
-                            if monitored_status_db is None:
-                                # not in db, might need to add, if we have a file on disk
-                                pass
-                            elif monitored_status_db != episode['monitored']:
-                                # monitored status changed and we don't know about it until now
-                                trace(f"(Monitor Status Mismatch) {episode['title']}")
-                                # pass
-                            elif not episode['monitored']:
-                                # Add unmonitored episode in sonarr to current episode list, otherwise it will be deleted from db
-                                current_episodes_sonarr.append(episode['id'])
-                                skipped_count += 1
-                                continue
+                    if monitored_status_db is None:
+                        # not in db, might need to add, if we have a file on disk
+                        pass
+                    elif monitored_status_db != episode['monitored']:
+                        # monitored status changed and we don't know about it until now
+                        trace(f"(Monitor Status Mismatch) {episode['title']}")
+                        # pass
+                    elif not episode['monitored']:
+                        # Add unmonitored episode in sonarr to current episode list, otherwise it will be deleted from db
+                        current_episodes_sonarr.append(episode['id'])
+                        skipped_count += 1
+                        continue
 
-                        try:
-                            bazarr_file_size = \
-                                os.path.getsize(path_mappings.path_replace(episode['episodeFile']['path']))
-                        except OSError:
-                            bazarr_file_size = 0
-                        if episode['episodeFile']['size'] > MINIMUM_VIDEO_SIZE or bazarr_file_size > MINIMUM_VIDEO_SIZE:
-                            # Add episodes in sonarr to current episode list
-                            current_episodes_sonarr.append(episode['id'])
+                if (episode['episodeFile']['size'] > MINIMUM_VIDEO_SIZE or
+                        check_actual_file_size(episode['episodeFile']['path'])):
+                    # Add episodes in sonarr to current episode list
+                    current_episodes_sonarr.append(episode['id'])
 
-                            # Parse episode data
-                            if episode['id'] in current_episodes_id_db_list:
-                                parsed_episode = episodeParser(episode)
-                                if not any([parsed_episode.items() <= x for x in current_episodes_db_kv]):
-                                    episodes_to_update.append(parsed_episode)
-                            else:
-                                episodes_to_add.append(episodeParser(episode))
+                    # Parse episode data
+                    if episode['id'] in current_episodes_in_db_row_as_dict:
+                        parsed_episode = episodeParser(episode)
+                        if not set(parsed_episode.items()).issubset(set(current_episodes_in_db_row_as_dict[episode['id']].items())):
+                            episodes_to_update.append(parsed_episode)
+                    else:
+                        episodes_to_add.append(episodeParser(episode))
     else:
         return
 
@@ -143,8 +146,7 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
             logging.error(f"BAZARR cannot delete episodes because of {e}")
         else:
             for removed_episode in episodes_to_delete:
-                if send_event:
-                    event_stream(type='episode', action='delete', payload=removed_episode)
+                event_stream(type='episode', action='delete', payload=removed_episode)
 
     # Insert new episodes in DB
     if len(episodes_to_add):
@@ -158,9 +160,7 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
                 episodes_to_update.append(added_episode)
             else:
                 store_subtitles(added_episode['path'], path_mappings.path_replace(added_episode['path']))
-
-                if send_event:
-                    event_stream(type='episode', payload=added_episode['sonarrEpisodeId'])
+                event_stream(type='episode', payload=added_episode['sonarrEpisodeId'])
 
     # Update existing episodes in DB
     if len(episodes_to_update):
@@ -174,32 +174,47 @@ def sync_episodes(series_id, send_event=True, defer_search=False):
                 logging.error(f"BAZARR cannot update episodes because of {e}")
             else:
                 store_subtitles(updated_episode['path'], path_mappings.path_replace(updated_episode['path']))
-
-                if send_event:
-                    event_stream(type='episode', action='update', payload=updated_episode['sonarrEpisodeId'])
+                event_stream(type='episode', action='update', payload=updated_episode['sonarrEpisodeId'])
 
     # Downloading missing subtitles
-    for episode in episodes_to_add + episodes_to_update:
-        episode_id = episode['sonarrEpisodeId']
+    series_data = database.execute(
+        select(TableShows.title,
+               TableShows.year,
+               TableShows.path)
+        .where(TableShows.sonarrSeriesId == series_id)
+    ).first()
+    if not series_data:
+        pass
+    else:
         if defer_search:
             logging.debug(
-                f'BAZARR searching for missing subtitles is deferred until scheduled task execution for this episode: '
-                f'{path_mappings.path_replace(episode["path"])}')
+                f'BAZARR searching for missing subtitles is deferred until scheduled task execution for this series: '
+                f'{series_data.title} ({series_data.year})')
         else:
-            mapped_episode_path = path_mappings.path_replace(episode["path"])
-            if os.path.exists(mapped_episode_path):
-                logging.debug(f'BAZARR downloading missing subtitles for this episode: {mapped_episode_path}')
-                episode_download_subtitles(episode_id, send_progress=True)
+            if os.path.exists(path_mappings.path_replace(series_data.path)):
+                logging.debug(f'BAZARR downloading missing subtitles for this series: {series_data.title} '
+                              f'({series_data.year})')
+                if _is_there_missing_subtitles(series_id=series_id):
+                    jobs_queue.feed_jobs_pending_queue(job_name=f'Downloading missing subtitles for {series_data.title}',
+                                                       module='subtitles.mass_download.series',
+                                                       func='series_download_subtitles',
+                                                       args=[],
+                                                       kwargs={'no': series_id},
+                                                       is_signalr=is_signalr,
+                                                       is_progress=True)
+                else:
+                    logging.debug(f'BAZARR no missing subtitles for this series: {series_data.title} '
+                                  f'({series_data.year})')
             else:
                 logging.debug(
-                    f'BAZARR cannot find this file yet (Sonarr may be slow to import episode between disks?). '
-                    f'Searching for missing subtitles is deferred until scheduled task execution for this episode'
-                    f': {mapped_episode_path}')
+                    f'BAZARR cannot find this series yet (Sonarr may be slow to import episode between disks?). '
+                    f'Searching for missing subtitles is deferred until scheduled task execution for this series'
+                    f': {series_data.title} ({series_data.year})')
 
     logging.debug(f'BAZARR All episodes from series ID {series_id} synced from Sonarr into database.')
 
 
-def sync_one_episode(episode_id, defer_search=False):
+def sync_one_episode(episode_id, defer_search=False, is_signalr=False):
     logging.debug(f'BAZARR syncing this specific episode from Sonarr: {episode_id}')
     apikey_sonarr = settings.sonarr.apikey
 
@@ -242,7 +257,7 @@ def sync_one_episode(episode_id, defer_search=False):
         else:
             event_stream(type='episode', action='delete', payload=int(episode_id))
             logging.debug(
-                f'BAZARR deleted this episode from the database:{path_mappings.path_replace(existing_episode["path"])}')
+                f'BAZARR deleted this episode from the database:{path_mappings.path_replace(existing_episode.path)}')
         return
 
     # Update existing episodes in DB
@@ -282,11 +297,61 @@ def sync_one_episode(episode_id, defer_search=False):
             f'BAZARR searching for missing subtitles is deferred until scheduled task execution for this episode: '
             f'{path_mappings.path_replace(episode["path"])}')
     else:
-        mapped_episode_path = path_mappings.path_replace(episode["path"])
-        if os.path.exists(mapped_episode_path):
-            logging.debug(f'BAZARR downloading missing subtitles for this episode: {mapped_episode_path}')
-            episode_download_subtitles(episode_id, send_progress=True)
+        series_title = database.execute(
+            select(TableShows.title)
+            .where(TableShows.sonarrSeriesId == episode["sonarrSeriesId"])
+        ).first()[0]
+        episode_full_title = (f'{series_title} - S{episode["season"]:02d}E{episode["episode"]:02d} - '
+                              f'{episode["title"]}')
+
+        if os.path.exists(path_mappings.path_replace(episode["path"])):
+            logging.debug(f'BAZARR downloading missing subtitles for this episode: {episode_full_title}')
+            if _is_there_missing_subtitles(episode_id=episode_id):
+                jobs_queue.feed_jobs_pending_queue(job_name=f'Downloading missing subtitles for {series_title}',
+                                                   module='subtitles.mass_download.series',
+                                                   func='episode_download_subtitles',
+                                                   args=[],
+                                                   kwargs={'no': episode_id},
+                                                   is_signalr=is_signalr)
+            else:
+                logging.debug(f'BAZARR no missing subtitles for this episode: {episode_full_title}')
         else:
             logging.debug(f'BAZARR cannot find this file yet (Sonarr may be slow to import episode between disks?). '
                           f'Searching for missing subtitles is deferred until scheduled task execution for this episode'
-                          f': {mapped_episode_path}')
+                          f': {episode_full_title}')
+
+
+def _is_there_missing_subtitles(series_id: int = None, episode_id: int = None) -> bool:
+    """
+    Determines whether there are missing subtitles for a given series or episode.
+
+    This function checks if there are missing subtitles based on the given
+    series ID or episode ID. If both `series_id` and `episode_id` are provided,
+    or if neither is provided, the function returns False. Otherwise, it evaluates
+    the specified conditions to determine if subtitles are missing for the
+    requested series or episode.
+
+    :param series_id: The ID of the series to check for missing subtitles.
+        Optional, defaults to None.
+    :param episode_id: The ID of the episode to check for missing subtitles.
+        Optional, defaults to None.
+    :return: Boolean indicating whether there are missing subtitles (`True`)
+        or not (`False`).
+    :rtype: bool
+    """
+    episodes_conditions = [(TableEpisodes.missing_subtitles.is_not(None)),
+                           (TableEpisodes.missing_subtitles != '[]')]
+    if all([series_id, episode_id]) or not any([series_id, episode_id]):
+        return False
+    elif series_id:
+        episodes_conditions.append(TableEpisodes.sonarrSeriesId == series_id)
+    elif episode_id:
+        episodes_conditions.append(TableEpisodes.sonarrEpisodeId == episode_id)
+    episodes_conditions += get_exclusion_clause('series')
+    missing_episodes = database.execute(
+        select(TableEpisodes.missing_subtitles)
+        .select_from(TableEpisodes)
+        .join(TableShows)
+        .where(reduce(operator.and_, episodes_conditions))) \
+        .all()
+    return len(missing_episodes) > 0
