@@ -4,6 +4,7 @@ import gc
 import os
 import logging
 import ast
+import time
 
 from subliminal_patch import core, search_external_subtitles
 
@@ -15,8 +16,9 @@ from app.config import settings
 from utilities.helper import get_subtitle_destination_folder
 from utilities.path_mappings import path_mappings
 from utilities.video_analyzer import embedded_subs_reader
-from app.event_handler import event_stream, show_progress, hide_progress
+from app.event_handler import event_stream
 from subtitles.indexer.utils import guess_external_subtitles, get_external_subtitles_path
+from app.jobs_queue import jobs_queue
 
 gc.enable()
 
@@ -94,8 +96,8 @@ def store_subtitles_movie(original_path, reversed_path, use_cache=True):
                     full_dest_folder_path = os.path.join(os.path.dirname(reversed_path), dest_folder)
             subtitles = guess_external_subtitles(full_dest_folder_path, subtitles, "movie",
                                                  previously_indexed_subtitles_to_exclude)
-        except Exception:
-            logging.exception("BAZARR unable to index external subtitles.")
+        except Exception as e:
+            logging.exception(f"BAZARR unable to index external subtitles for this file {reversed_path}: {repr(e)}")
         else:
             for subtitle, language in subtitles.items():
                 valid_language = False
@@ -151,7 +153,7 @@ def store_subtitles_movie(original_path, reversed_path, use_cache=True):
     return actual_subtitles
 
 
-def list_missing_subtitles_movies(no=None, send_event=True):
+def list_missing_subtitles_movies(no=None):
     stmt = select(TableMovies.radarrId,
                   TableMovies.subtitles,
                   TableMovies.profileId,
@@ -270,35 +272,31 @@ def list_missing_subtitles_movies(no=None, send_event=True):
             .values(missing_subtitles=missing_subtitles_text)
             .where(TableMovies.radarrId == movie_subtitles.radarrId))
 
-        if send_event:
-            event_stream(type='movie', payload=movie_subtitles.radarrId)
-            event_stream(type='movie-wanted', action='update', payload=movie_subtitles.radarrId)
-    if send_event:
-        event_stream(type='badges')
+        event_stream(type='movie', payload=movie_subtitles.radarrId)
+        event_stream(type='movie-wanted', action='update', payload=movie_subtitles.radarrId)
+    event_stream(type='badges')
 
 
-def movies_full_scan_subtitles(use_cache=None):
+def movies_full_scan_subtitles(job_id=None, use_cache=None):
+    if not job_id:
+        jobs_queue.add_job_from_function("Indexing all existing movies subtitles", is_progress=True)
+        return
+
     if use_cache is None:
         use_cache = settings.radarr.use_ffprobe_cache
 
     movies = database.execute(
-        select(TableMovies.path))\
+        select(TableMovies.path, TableMovies.title))\
         .all()
 
-    count_movies = len(movies)
-    for i, movie in enumerate(movies):
-        show_progress(id='movies_disk_scan',
-                      header='Full disk scan...',
-                      name='Movies subtitles',
-                      value=i,
-                      count=count_movies)
+    jobs_queue.update_job_progress(job_id=job_id, progress_max=len(movies), progress_message='Indexing')
+    for i, movie in enumerate(movies, start=1):
+        jobs_queue.update_job_progress(job_id=job_id, progress_value=i, progress_message=movie.title)
         store_subtitles_movie(movie.path, path_mappings.path_replace_movie(movie.path), use_cache=use_cache)
 
-    show_progress(id='movies_disk_scan',
-                  header='Full disk scan...',
-                  name='Movies subtitles',
-                  value=count_movies,
-                  count=count_movies)
+    logging.info('BAZARR All existing movie subtitles indexed from disk.')
+
+    jobs_queue.update_job_name(job_id=job_id, new_job_name="Indexed all existing movies subtitles")
 
     gc.collect()
 
