@@ -15,8 +15,9 @@ from app.config import settings
 from utilities.helper import get_subtitle_destination_folder
 from utilities.path_mappings import path_mappings
 from utilities.video_analyzer import embedded_subs_reader
-from app.event_handler import event_stream, show_progress, hide_progress
+from app.event_handler import event_stream
 from subtitles.indexer.utils import guess_external_subtitles, get_external_subtitles_path
+from app.jobs_queue import jobs_queue
 
 gc.enable()
 
@@ -93,8 +94,8 @@ def store_subtitles(original_path, reversed_path, use_cache=True):
                     full_dest_folder_path = os.path.join(os.path.dirname(reversed_path), dest_folder)
             subtitles = guess_external_subtitles(full_dest_folder_path, subtitles, "series",
                                                  previously_indexed_subtitles_to_exclude)
-        except Exception:
-            logging.exception("BAZARR unable to index external subtitles.")
+        except Exception as e:
+            logging.exception(f"BAZARR unable to index external subtitles for this file {reversed_path}: {repr(e)}")
         else:
             for subtitle, language in subtitles.items():
                 valid_language = False
@@ -150,7 +151,7 @@ def store_subtitles(original_path, reversed_path, use_cache=True):
     return actual_subtitles
 
 
-def list_missing_subtitles(no=None, epno=None, send_event=True):
+def list_missing_subtitles(no=None, epno=None):
     stmt = select(TableShows.sonarrSeriesId,
                   TableEpisodes.sonarrEpisodeId,
                   TableEpisodes.subtitles,
@@ -276,35 +277,35 @@ def list_missing_subtitles(no=None, epno=None, send_event=True):
             .values(missing_subtitles=missing_subtitles_text)
             .where(TableEpisodes.sonarrEpisodeId == episode_subtitles.sonarrEpisodeId))
 
-        if send_event:
-            event_stream(type='episode', payload=episode_subtitles.sonarrEpisodeId)
-            event_stream(type='episode-wanted', action='update', payload=episode_subtitles.sonarrEpisodeId)
-    if send_event:
-        event_stream(type='badges')
+        event_stream(type='episode', payload=episode_subtitles.sonarrEpisodeId)
+        event_stream(type='episode-wanted', action='update', payload=episode_subtitles.sonarrEpisodeId)
+    event_stream(type='badges')
 
 
-def series_full_scan_subtitles(use_cache=None):
+def series_full_scan_subtitles(job_id=None, use_cache=None):
+    if not job_id:
+        jobs_queue.add_job_from_function("Indexing all existing episodes subtitles", is_progress=True)
+        return
+
     if use_cache is None:
         use_cache = settings.sonarr.use_ffprobe_cache
 
     episodes = database.execute(
-        select(TableEpisodes.path))\
-        .all()
+        select(TableEpisodes.path, TableShows.title, TableEpisodes.title.label("episodeTitle"), TableEpisodes.season, TableEpisodes.episode)
+        .select_from(TableEpisodes)
+        .join(TableShows)
+    ).all()
 
-    count_episodes = len(episodes)
-    for i, episode in enumerate(episodes):
-        show_progress(id='episodes_disk_scan',
-                      header='Full disk scan...',
-                      name='Episodes subtitles',
-                      value=i,
-                      count=count_episodes)
+    jobs_queue.update_job_progress(job_id=job_id, progress_max=len(episodes), progress_message='Indexing')
+    for i, episode in enumerate(episodes, start=1):
+        jobs_queue.update_job_progress(
+            job_id=job_id, progress_value=i,
+            progress_message=f"{episode.title} - S{episode.season:02d}E{episode.episode:02d} - {episode.episodeTitle}")
         store_subtitles(episode.path, path_mappings.path_replace(episode.path), use_cache=use_cache)
 
-    show_progress(id='episodes_disk_scan',
-                  header='Full disk scan...',
-                  name='Episodes subtitles',
-                  value=count_episodes,
-                  count=count_episodes)
+    logging.info('BAZARR All existing episode subtitles indexed from disk.')
+
+    jobs_queue.update_job_name(job_id=job_id, new_job_name="Indexed all existing series subtitles")
 
     gc.collect()
 
