@@ -12,7 +12,7 @@ from sqlalchemy import and_, or_
 from app.config import settings
 from app.database import get_exclusion_clause, get_audio_profile_languages, TableShows, TableEpisodes, TableMovies, \
     TableHistory, TableHistoryMovie, database, select, func, get_profiles_list
-from app.event_handler import show_progress, hide_progress
+from app.jobs_queue import jobs_queue
 from app.get_providers import get_providers
 from app.notifier import send_notifications, send_notifications_movie
 from radarr.history import history_log_movie
@@ -28,222 +28,232 @@ def upgrade_subtitles():
     use_radarr = settings.general.use_radarr
 
     if use_sonarr:
-        episodes_to_upgrade = get_upgradable_episode_subtitles()
-        episodes_data = [{
-            'id': x.id,
-            'seriesTitle': x.seriesTitle,
-            'season': x.season,
-            'episode': x.episode,
-            'title': x.title,
-            'language': x.language,
-            'audio_language': x.audio_language,
-            'video_path': x.video_path,
-            'sceneName': x.sceneName,
-            'score': x.score,
-            'sonarrEpisodeId': x.sonarrEpisodeId,
-            'sonarrSeriesId': x.sonarrSeriesId,
-            'subtitles_path': x.subtitles_path,
-            'path': x.path,
-            'profileId': x.profileId,
-            'external_subtitles': [y[1] for y in ast.literal_eval(x.external_subtitles) if y[1]],
-        } for x in database.execute(
-            select(TableHistory.id,
-                   TableShows.title.label('seriesTitle'),
-                   TableEpisodes.season,
-                   TableEpisodes.episode,
-                   TableEpisodes.title,
-                   TableHistory.language,
-                   TableEpisodes.audio_language,
-                   TableHistory.video_path,
-                   TableEpisodes.sceneName,
-                   TableHistory.score,
-                   TableHistory.sonarrEpisodeId,
-                   TableHistory.sonarrSeriesId,
-                   TableHistory.subtitles_path,
-                   TableEpisodes.path,
-                   TableShows.profileId,
-                   TableEpisodes.subtitles.label('external_subtitles'))
-            .select_from(TableHistory)
-            .join(TableShows, onclause=TableHistory.sonarrSeriesId == TableShows.sonarrSeriesId)
-            .join(TableEpisodes, onclause=TableHistory.sonarrEpisodeId == TableEpisodes.sonarrEpisodeId))
-            .all() if _language_still_desired(x.language, x.profileId) and
-            x.video_path == x.path
-        ]
-
-        for item in episodes_data:
-            # do not consider subtitles that do not exist on disk anymore
-            if item['subtitles_path'] not in item['external_subtitles']:
-                continue
-
-            # Mark upgradable and get original_id
-            item.update({'original_id': episodes_to_upgrade.get(item['id'])})
-            item.update({'upgradable': bool(item['original_id'])})
-
-            # cleanup the unused attributes
-            del item['path']
-            del item['external_subtitles']
-
-        # Make sure to keep only upgradable episode subtitles
-        episodes_data = [x for x in episodes_data if 'upgradable' in x and x['upgradable']]
-
-        count_episode_to_upgrade = len(episodes_data)
-
-        for i, episode in enumerate(episodes_data):
-            providers_list = get_providers()
-
-            show_progress(id='upgrade_episodes_progress',
-                          header='Upgrading episodes subtitles...',
-                          name=f'{episode["seriesTitle"]} - S{episode["season"]:02d}E{episode["episode"]:02d} - {episode["title"]}',
-                          value=i,
-                          count=count_episode_to_upgrade)
-
-            if not providers_list:
-                logging.info("BAZARR All providers are throttled")
-                return
-
-            language, is_forced, is_hi = parse_language_string(episode['language'])
-            if is_hi and not _is_hi_required(language, episode['profileId']):
-                is_hi = 'False'
-
-            audio_language_list = get_audio_profile_languages(episode['audio_language'])
-            if len(audio_language_list) > 0:
-                audio_language = audio_language_list[0]['name']
-            else:
-                audio_language = 'None'
-
-            result = list(generate_subtitles(path_mappings.path_replace(episode['video_path']),
-                                             [(language, is_hi, is_forced)],
-                                             audio_language,
-                                             str(episode['sceneName']),
-                                             episode['seriesTitle'],
-                                             'series',
-                                             episode['profileId'],
-                                             forced_minimum_score=int(episode['score']) + 1,
-                                             is_upgrade=True,
-                                             previous_subtitles_to_delete=path_mappings.path_replace(
-                                                 episode['subtitles_path'])))
-
-            if result:
-                if isinstance(result, list) and len(result):
-                    result = result[0]
-                if isinstance(result, tuple) and len(result):
-                    result = result[0]
-                store_subtitles(episode['video_path'], path_mappings.path_replace(episode['video_path']))
-                history_log(3, episode['sonarrSeriesId'], episode['sonarrEpisodeId'], result,
-                            upgraded_from_id=episode['original_id'])
-                send_notifications(episode['sonarrSeriesId'], episode['sonarrEpisodeId'], result.message)
-
-        show_progress(id='upgrade_episodes_progress',
-                      header='Upgrading episodes subtitles...',
-                      name='',
-                      value=count_episode_to_upgrade,
-                      count=count_episode_to_upgrade)
+        upgrade_episodes_subtitles()
 
     if use_radarr:
-        movies_to_upgrade = get_upgradable_movies_subtitles()
-        movies_data = [{
-            'id': x.id,
-            'title': x.title,
-            'language': x.language,
-            'audio_language': x.audio_language,
-            'video_path': x.video_path,
-            'sceneName': x.sceneName,
-            'score': x.score,
-            'radarrId': x.radarrId,
-            'path': x.path,
-            'profileId': x.profileId,
-            'subtitles_path': x.subtitles_path,
-            'external_subtitles': [y[1] for y in ast.literal_eval(x.external_subtitles) if y[1]],
-        } for x in database.execute(
-            select(TableHistoryMovie.id,
-                   TableMovies.title,
-                   TableHistoryMovie.language,
-                   TableMovies.audio_language,
-                   TableHistoryMovie.video_path,
-                   TableMovies.sceneName,
-                   TableHistoryMovie.score,
-                   TableHistoryMovie.radarrId,
-                   TableHistoryMovie.subtitles_path,
-                   TableMovies.path,
-                   TableMovies.profileId,
-                   TableMovies.subtitles.label('external_subtitles'))
-            .select_from(TableHistoryMovie)
-            .join(TableMovies, onclause=TableHistoryMovie.radarrId == TableMovies.radarrId))
-            .all() if _language_still_desired(x.language, x.profileId) and
-            x.video_path == x.path
-        ]
-
-        for item in movies_data:
-            # do not consider subtitles that do not exist on disk anymore
-            if item['subtitles_path'] not in item['external_subtitles']:
-                continue
-
-            # Mark upgradable and get original_id
-            item.update({'original_id': movies_to_upgrade.get(item['id'])})
-            item.update({'upgradable': bool(item['original_id'])})
-
-            # cleanup the unused attributes
-            del item['path']
-            del item['external_subtitles']
-
-        # Make sure to keep only upgradable movie subtitles
-        movies_data = [x for x in movies_data if 'upgradable' in x and x['upgradable']]
-
-        count_movie_to_upgrade = len(movies_data)
-
-        for i, movie in enumerate(movies_data):
-            providers_list = get_providers()
-
-            show_progress(id='upgrade_movies_progress',
-                          header='Upgrading movies subtitles...',
-                          name=movie['title'],
-                          value=i,
-                          count=count_movie_to_upgrade)
-
-            if not providers_list:
-                logging.info("BAZARR All providers are throttled")
-                return
-
-            language, is_forced, is_hi = parse_language_string(movie['language'])
-            if is_hi and not _is_hi_required(language, movie['profileId']):
-                is_hi = 'False'
-
-            audio_language_list = get_audio_profile_languages(movie['audio_language'])
-            if len(audio_language_list) > 0:
-                audio_language = audio_language_list[0]['name']
-            else:
-                audio_language = 'None'
-
-            result = list(generate_subtitles(path_mappings.path_replace_movie(movie['video_path']),
-                                             [(language, is_hi, is_forced)],
-                                             audio_language,
-                                             str(movie['sceneName']),
-                                             movie['title'],
-                                             'movie',
-                                             movie['profileId'],
-                                             forced_minimum_score=int(movie['score']) + 1,
-                                             is_upgrade=True,
-                                             previous_subtitles_to_delete=path_mappings.path_replace_movie(
-                                                 movie['subtitles_path'])))
-            if result:
-                if isinstance(result, list) and len(result):
-                    result = result[0]
-                if isinstance(result, tuple) and len(result):
-                    result = result[0]
-                store_subtitles_movie(movie['video_path'],
-                                      path_mappings.path_replace_movie(movie['video_path']))
-                history_log_movie(3, movie['radarrId'], result, upgraded_from_id=movie['original_id'])
-                send_notifications_movie(movie['radarrId'], result.message)
-
-        show_progress(id='upgrade_movies_progress',
-                      header='Upgrading movies subtitles...',
-                      name='',
-                      value=count_movie_to_upgrade,
-                      count=count_movie_to_upgrade)
+        upgrade_movies_subtitles()
 
     logging.info('BAZARR Finished searching for Subtitles to upgrade. Check History for more information.')
 
 
+def upgrade_episodes_subtitles(job_id=None):
+    if not job_id:
+        jobs_queue.add_job_from_function("Trying to upgrade episodes subtitles", is_progress=True)
+        return
+
+    episodes_to_upgrade = get_upgradable_episode_subtitles()
+    episodes_data = [{
+        'id': x.id,
+        'seriesTitle': x.seriesTitle,
+        'season': x.season,
+        'episode': x.episode,
+        'title': x.title,
+        'language': x.language,
+        'audio_language': x.audio_language,
+        'video_path': x.video_path,
+        'sceneName': x.sceneName,
+        'score': x.score,
+        'sonarrEpisodeId': x.sonarrEpisodeId,
+        'sonarrSeriesId': x.sonarrSeriesId,
+        'subtitles_path': x.subtitles_path,
+        'path': x.path,
+        'profileId': x.profileId,
+        'external_subtitles': [y[1] for y in ast.literal_eval(x.external_subtitles) if y[1]],
+    } for x in database.execute(
+        select(TableHistory.id,
+               TableShows.title.label('seriesTitle'),
+               TableEpisodes.season,
+               TableEpisodes.episode,
+               TableEpisodes.title,
+               TableHistory.language,
+               TableEpisodes.audio_language,
+               TableHistory.video_path,
+               TableEpisodes.sceneName,
+               TableHistory.score,
+               TableHistory.sonarrEpisodeId,
+               TableHistory.sonarrSeriesId,
+               TableHistory.subtitles_path,
+               TableEpisodes.path,
+               TableShows.profileId,
+               TableEpisodes.subtitles.label('external_subtitles'))
+        .select_from(TableHistory)
+        .join(TableShows, onclause=TableHistory.sonarrSeriesId == TableShows.sonarrSeriesId)
+        .join(TableEpisodes, onclause=TableHistory.sonarrEpisodeId == TableEpisodes.sonarrEpisodeId))
+    .all() if _language_still_desired(x.language, x.profileId) and
+              x.video_path == x.path
+    ]
+
+    for item in episodes_data:
+        # do not consider subtitles that do not exist on disk anymore
+        if item['subtitles_path'] not in item['external_subtitles']:
+            continue
+
+        # Mark upgradable and get original_id
+        item.update({'original_id': episodes_to_upgrade.get(item['id'])})
+        item.update({'upgradable': bool(item['original_id'])})
+
+        # cleanup the unused attributes
+        del item['path']
+        del item['external_subtitles']
+
+    # Make sure to keep only upgradable episode subtitles
+    episodes_data = [x for x in episodes_data if 'upgradable' in x and x['upgradable']]
+
+    count_episode_to_upgrade = len(episodes_data)
+    jobs_queue.update_job_progress(job_id=job_id, progress_max=count_episode_to_upgrade)
+
+    if count_episode_to_upgrade == 0:
+        jobs_queue.update_job_progress(job_id=job_id, progress_value='max')
+
+    for i, episode in enumerate(episodes_data, start=1):
+        providers_list = get_providers()
+
+        jobs_queue.update_job_progress(job_id=job_id, progress_value=i,
+                                       progress_message=f'{episode["seriesTitle"]} - S{episode["season"]:02d}E'
+                                                        f'{episode["episode"]:02d} - {episode["title"]}')
+
+        if not providers_list:
+            logging.info("BAZARR All providers are throttled")
+            return
+
+        language, is_forced, is_hi = parse_language_string(episode['language'])
+        if is_hi and not _is_hi_required(language, episode['profileId']):
+            is_hi = 'False'
+
+        audio_language_list = get_audio_profile_languages(episode['audio_language'])
+        if len(audio_language_list) > 0:
+            audio_language = audio_language_list[0]['name']
+        else:
+            audio_language = 'None'
+
+        result = list(generate_subtitles(path_mappings.path_replace(episode['video_path']),
+                                         [(language, is_hi, is_forced)],
+                                         audio_language,
+                                         str(episode['sceneName']),
+                                         episode['seriesTitle'],
+                                         'series',
+                                         episode['profileId'],
+                                         forced_minimum_score=int(episode['score']) + 1,
+                                         is_upgrade=True,
+                                         previous_subtitles_to_delete=path_mappings.path_replace(
+                                             episode['subtitles_path']),
+                                         job_id=job_id))
+
+        if result:
+            if isinstance(result, list) and len(result):
+                result = result[0]
+            if isinstance(result, tuple) and len(result):
+                result = result[0]
+            store_subtitles(episode['video_path'], path_mappings.path_replace(episode['video_path']))
+            history_log(3, episode['sonarrSeriesId'], episode['sonarrEpisodeId'], result,
+                        upgraded_from_id=episode['original_id'])
+            send_notifications(episode['sonarrSeriesId'], episode['sonarrEpisodeId'], result.message)
+    jobs_queue.update_job_name(job_id=job_id, new_job_name='Tried to upgrade episodes subtitles')
+
+
+def upgrade_movies_subtitles(job_id=None):
+    if not job_id:
+        jobs_queue.add_job_from_function("Trying to upgrade movies subtitles", is_progress=True)
+        return
+
+    movies_to_upgrade = get_upgradable_movies_subtitles()
+    movies_data = [{
+        'id': x.id,
+        'title': x.title,
+        'language': x.language,
+        'audio_language': x.audio_language,
+        'video_path': x.video_path,
+        'sceneName': x.sceneName,
+        'score': x.score,
+        'radarrId': x.radarrId,
+        'path': x.path,
+        'profileId': x.profileId,
+        'subtitles_path': x.subtitles_path,
+        'external_subtitles': [y[1] for y in ast.literal_eval(x.external_subtitles) if y[1]],
+    } for x in database.execute(
+        select(TableHistoryMovie.id,
+               TableMovies.title,
+               TableHistoryMovie.language,
+               TableMovies.audio_language,
+               TableHistoryMovie.video_path,
+               TableMovies.sceneName,
+               TableHistoryMovie.score,
+               TableHistoryMovie.radarrId,
+               TableHistoryMovie.subtitles_path,
+               TableMovies.path,
+               TableMovies.profileId,
+               TableMovies.subtitles.label('external_subtitles'))
+        .select_from(TableHistoryMovie)
+        .join(TableMovies, onclause=TableHistoryMovie.radarrId == TableMovies.radarrId))
+    .all() if _language_still_desired(x.language, x.profileId) and
+              x.video_path == x.path
+    ]
+
+    for item in movies_data:
+        # do not consider subtitles that do not exist on disk anymore
+        if item['subtitles_path'] not in item['external_subtitles']:
+            continue
+
+        # Mark upgradable and get original_id
+        item.update({'original_id': movies_to_upgrade.get(item['id'])})
+        item.update({'upgradable': bool(item['original_id'])})
+
+        # cleanup the unused attributes
+        del item['path']
+        del item['external_subtitles']
+
+    # Make sure to keep only upgradable movie subtitles
+    movies_data = [x for x in movies_data if 'upgradable' in x and x['upgradable']]
+
+    count_movie_to_upgrade = len(movies_data)
+    jobs_queue.update_job_progress(job_id=job_id, progress_max=count_movie_to_upgrade)
+
+    if count_movie_to_upgrade == 0:
+        jobs_queue.update_job_progress(job_id=job_id, progress_value='max')
+
+    for i, movie in enumerate(movies_data, start=1):
+        providers_list = get_providers()
+
+        jobs_queue.update_job_progress(job_id=job_id, progress_value=i, progress_message=movie['title'])
+
+        if not providers_list:
+            logging.info("BAZARR All providers are throttled")
+            return
+
+        language, is_forced, is_hi = parse_language_string(movie['language'])
+        if is_hi and not _is_hi_required(language, movie['profileId']):
+            is_hi = 'False'
+
+        audio_language_list = get_audio_profile_languages(movie['audio_language'])
+        if len(audio_language_list) > 0:
+            audio_language = audio_language_list[0]['name']
+        else:
+            audio_language = 'None'
+
+        result = list(generate_subtitles(path_mappings.path_replace_movie(movie['video_path']),
+                                         [(language, is_hi, is_forced)],
+                                         audio_language,
+                                         str(movie['sceneName']),
+                                         movie['title'],
+                                         'movie',
+                                         movie['profileId'],
+                                         forced_minimum_score=int(movie['score']) + 1,
+                                         is_upgrade=True,
+                                         previous_subtitles_to_delete=path_mappings.path_replace_movie(
+                                             movie['subtitles_path']),
+                                         job_id=job_id))
+        if result:
+            if isinstance(result, list) and len(result):
+                result = result[0]
+            if isinstance(result, tuple) and len(result):
+                result = result[0]
+            store_subtitles_movie(movie['video_path'],
+                                  path_mappings.path_replace_movie(movie['video_path']))
+            history_log_movie(3, movie['radarrId'], result, upgraded_from_id=movie['original_id'])
+            send_notifications_movie(movie['radarrId'], result.message)
+    jobs_queue.update_job_name(job_id=job_id, new_job_name='Tried to upgrade movies subtitles')
+
+
 def get_queries_condition_parameters():
     days_to_upgrade_subs = settings.general.days_to_upgrade_subs
     minimum_timestamp = (datetime.now() - timedelta(days=int(days_to_upgrade_subs)))
