@@ -11,6 +11,7 @@ from glob import glob
 
 from app.get_args import args
 from app.config import settings
+from app.jobs_queue import jobs_queue
 from utilities.central import restart_bazarr
 
 
@@ -45,7 +46,11 @@ def get_backup_files(fullpath=True):
         } for x in file_list]
 
 
-def backup_to_zip():
+def backup_to_zip(job_id=None):
+    if not job_id:
+        jobs_queue.add_job_from_function("Backing up Database and Configuration File", is_progress=False)
+        return
+
     now = datetime.now()
     database_backup_file = None
     now_string = now.strftime("%Y.%m.%d_%H.%M.%S")
@@ -86,6 +91,8 @@ def backup_to_zip():
             logging.debug('Database file is not included in backup. See previous exception')
         backupZip.write(config_file, 'config.yaml')
 
+    jobs_queue.update_job_name(job_id=job_id, new_job_name="Backed up Database and Configuration File")
+
 
 def restore_from_backup():
     if os.path.isfile(os.path.join(get_restore_path(), 'config.yaml')):
