@@ -1204,7 +1204,7 @@ def save_subtitles(file_path, subtitles, single=False, directory=None, chmod=Non
     saved_subtitles = []
     for subtitle in subtitles:
         # check if HI mods will be used to get the proper name for the subtitles file
-        must_remove_hi = 'remove_HI' in subtitle.mods
+        must_remove_hi = subtitle.mods and 'remove_HI' in subtitle.mods
 
         # check content
         if subtitle.content is None or subtitle.text is None:
