@@ -2,5 +2,5 @@
 
 from __future__ import absolute_import
 from .registry import registry
-from .mods import hearing_impaired, ocr_fixes, fps, offset, common, color
+from .mods import hearing_impaired, ocr_fixes, fps, offset, common, color, emoji
 from .main import SubtitleModifications, SubMod
